@@ -4,7 +4,7 @@ use warnings;
 use autodie;
 package CPAN::Meta::Converter;
 BEGIN {
-  $CPAN::Meta::Converter::VERSION = '2.101590';
+  $CPAN::Meta::Converter::VERSION = '2.101591';
 }
 # ABSTRACT: Convert CPAN distribution metadata structures
 
@@ -465,7 +465,7 @@ sub _upgrade_optional_features {
 }
 
 my $optional_features_2_spec = {
-  description => \&_keep_or_unknown,
+  description => \&_keep,
   prereqs => \&_cleanup_prereqs,
   ':custom'  => \&_prefix_custom,
 };
@@ -1243,7 +1243,7 @@ CPAN::Meta::Converter - Convert CPAN distribution metadata structures
 
 =head1 VERSION
 
-version 2.101590
+version 2.101591
 
 =head1 SYNOPSIS
 
@@ -1275,34 +1275,59 @@ be assumed.
 
   my $new_struct = $cmc->convert( version => "2" );
 
-Returns a new hash reference with the metadata converted to a
-different form.
+Returns a new hash reference with the metadata converted to a different form.
+C<convert> will die if any conversion/standardization still results in an
+invalid structure.
 
 Valid parameters include:
 
+=over
+
+=item *
+
+C<version> -- Indicates the desired specification version (e.g. "1.0", "1.1" ... "1.4", "2").
+Defaults to the latest version of the CPAN Meta Spec.
+
+=back
+
+Conversion proceeds through each version in turn.  For example, a version 1.2
+structure might be converted to 1.3 then 1.4 then finally to version 2. The
+conversion process attempts to clean-up simple errors and standardize data.
+For example, if C<author> is given as a scalar, it will converted to an array
+reference containing the item. (Converting a structure to its own version will
+also clean-up and standardize.)
+
+When data are cleaned and standardized, missing or invalid fields will be
+replaced with sensible defaults when possible.  This may be lossy or imprecise.
+For example, some badly structured META.yml files on CPAN have prerequisite
+modules listed as both keys and values:
+
+  requires => { 'Foo::Bar' => 'Bam::Baz' }
+
+These would be split and each converted to a prerequisite with a minimum
+version of zero.
+
+When some mandatory fields are missing or invalid, the conversion will attempt
+to provide a sensible default or will fill them with a value of 'unknown'.  For
+example a missing or unrecognized C<license> field will result in a C<license>
+field of 'unknown'.  Fields that may get an 'unknown' include:
+
 =over 4
 
 =item *
 
-version
+abstract
 
-Indicates the desired specification version (e.g. "1.0", "1.1" ... "1.4", "2").
-Defaults to the latest version of the CPAN Meta Spec.
+=item *
+
+author
+
+=item *
+
+license
 
 =back
 
-The conversion process attempts to clean-up simple errors and standardize data
-during converstion.  For example, if C<author> is given as a scalar, it will
-converted to an array reference containing the item, or if a mandatory
-C<license> field is missing, it will be added as "unknown".
-
-Conversion proceeds through each version in turn.  For example, a version 1.2
-structure is converted to 1.3 then 1.4 then finally version 2.  Converting a
-structure to its own version will still clean-up and standardize the structure.
-
-C<convert> will die if any conversion/standardization still results in an
-invalid structure.
-
 =head1 BUGS
 
 Please report any bugs or feature using the CPAN Request Tracker.
